========
Material
========

The Material commands are used to define the materials in a model.


Create materials
-----------------

In Mdb
~~~~~~

.. autoclass:: abaqus.Material.MaterialModel.MaterialModel
    :noindex:

    .. autoclasstoc::

In Odb
~~~~~~

.. autoclass:: abaqus.Material.MaterialOdb.MaterialOdb
    :noindex:

    .. autoclasstoc::


Assign properties to the material
---------------------------------

.. autoclass:: abaqus.Material.Material.Material
    :noindex:

    .. autoclasstoc::

.. This is a comment ro supress the warning "(ERROR/3) Document may not end with a transition."
